import os
import sys
import json
from random import Random

from more_itertools import zip_equal

from ahisto_named_entity_search.recognition import NerModel
from ahisto_named_entity_search.search import TaggedSentence

RANDOM_SEED = 42

if __name__ == '__main__':
    assert len(sys.argv) == 2

    input_tagged_sentence_basename = sys.argv[1]

    input_tagged_sentences = TaggedSentence.load(input_tagged_sentence_basename)
    input_tagged_sentences = list(input_tagged_sentences)

    output_tagged_sentence_basename = f'{input_tagged_sentence_basename}_automatically_tagged'
    try:
        output_tagged_sentences = TaggedSentence.load(output_tagged_sentence_basename)
        output_tagged_sentences = list(output_tagged_sentences)
    except FileNotFoundError:
        completion_models = [
            NerModel.load('model_ner_manatee_all_only-relevant_parallel_002'),
            NerModel.load('model_ner_manatee_non-crossing_only-relevant_fair-sequential_002'),
            NerModel('Babelscape/wikineural-multilingual-ner',
                     labels=['O', 'B-PER', 'I-PER', 'B-ORG', 'I-ORG', 'B-LOC', 'I-LOC', 'B-MISC', 'I-MISC'])
        ]

        input_sentences = [tagged_sentence.sentence for tagged_sentence in input_tagged_sentences]
        model_tagged_sentences = NerModel.tag_sentences_with_multiple_models(completion_models, input_sentences)
        output_tagged_sentences = []
        for input_tagged_sentence, model_tagged_sentence in zip_equal(input_tagged_sentences, model_tagged_sentences):
            output_tagged_sentence = model_tagged_sentence + input_tagged_sentence
            output_tagged_sentences.append(output_tagged_sentence)
        Random(RANDOM_SEED).shuffle(output_tagged_sentences)

        TaggedSentence.save(output_tagged_sentence_basename, output_tagged_sentences)

    assert len(input_tagged_sentences) == len(output_tagged_sentences)
